@@ -721,8 +721,7 @@ baobab_set_excluded_locations (gchar **uris)
 {
 	gint i;
 
-	g_slist_foreach (baobab.excluded_locations, (GFunc) g_object_unref, NULL);
-	g_slist_free (baobab.excluded_locations);
+	g_slist_free_full (baobab.excluded_locations, g_object_unref);
 	baobab.excluded_locations = NULL;
 	for (i = 0; uris[i] != NULL; ++i) {
 		baobab.excluded_locations = g_slist_prepend (baobab.excluded_locations,
@@ -896,8 +895,7 @@ baobab_shutdown (void)
 
 	g_free (baobab.selected_path);
 
-	g_slist_foreach (baobab.excluded_locations, (GFunc) g_object_unref, NULL);
-	g_slist_free (baobab.excluded_locations);
+	g_slist_free_full (baobab.excluded_locations, g_object_unref);
 
 	if (baobab.ui_settings) {
 		g_object_unref (baobab.ui_settings);
@@ -932,7 +930,7 @@ create_context_menu (void)
 
 	menu->snapshot_item = gtk_image_menu_item_new_with_label (_("Save screenshot"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu->snapshot_item),
-				       gtk_image_new_from_file (BAOBAB_PIX_DIR "shot.png"));
+				       gtk_image_new_from_icon_name ("applets-screenshooter", GTK_ICON_SIZE_MENU));
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu->widget),
 			       menu->up_item);
@@ -1193,6 +1191,8 @@ initialize_charts (void)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (baobab.chart_type_combo), 0);
 	}
 
+	g_free (saved_chart);
+
 	check_drop_targets (FALSE);
 }
 
@@ -1317,7 +1317,7 @@ main (int argc, char *argv[])
 		g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
 		                 (GSourceFunc) start_proc_on_command_line,
 		                 file,
-		                 (GDestroyNotify) g_object_unref);
+		                 g_object_unref);
 	}
 	g_strfreev (directories);
 
